Learn R Programming

axisandallies (version 0.1.1)

info_units: Unit Information

Description

Gives basic information about the units in axis and allies

Usage

info_units(unit, write_to_console = TRUE)

Value

Describes the unit's attack, defense, movement, and cost, and other details in several lines of text

Arguments

unit

A unit in axis and allies spring 1942 in all lowercase letters

write_to_console

If true, writes the output to the console, if false, returns as a vector

Examples

Run this code
info_units("artillery")

Run the code above in your browser using DataLab