IPC Damage done by strategic bombing raid to industrial complex, number of offense fighters left if using optional rules, number of bombers left, number of defense fighters left if using optional rules in lines of text
Arguments
offense_fighters
Number of fighters brought to the strategic bombing raid if using optional rules for strategic bombing raids which include fighters
offense_bombers
Number of bombers brought to bombing raid
defense_fighters
Number of fighters defending in the strategic bombing raid if using optional rules for strategic bombing raids which include fighters
aagun
Is an anti aircraft gun present on the defending side
write_to_console
If true, writes the output to the console, if false, returns as a vector