powered by
Gives basic information about the units in axis and allies
info_units(unit, write_to_console = TRUE)
Describes the unit's attack, defense, movement, and cost, and other details in several lines of text
A unit in axis and allies spring 1942 in all lowercase letters
If true, writes the output to the console, if false, returns as a vector
info_units("artillery")
Run the code above in your browser using DataLab